==> bitfront-library-7.2.2.tgz: package/src/app/shared/component/index.ts <==
export * from "./bit-boton-ayuda.component";
export * from "./bit-breadcrumb.component";
export * from "./bit-column-boolean.component";
export * from "./bit-control-messages.component";
export * from "./bit-dialog.component";
export * from "./bit-domain-value.component";
export * from "./bit-editor.component";
export * from "./bit-footer.component";
export * from "./bit-form-upload.component";
export * from "./bit-header.component";
export * from "./bit-help.component";
export * from "./bit-input.component";
export * from "./bit-loading.component";
export * from "./bit-notification-front.component";
export * from "./bit-notification.component";
export * from "./bit-select-multiple.component";
export * from "./bit-select.component";
export * from "./bit-toolbar.component";
export * from "./bit-upload.component";
export * from "./bit-user-controls.component";
//nuevos inputs
export * from "./form";
//store
export * from "./bit-store-breadcrumb.component";
export * from "./bit-store-footer.component";
export * from "./bit-store-header.component";
export * from "./bit-store-toolbar.component";

import { BitDialogComponent } from "./bit-dialog.component";
import { BitNotificationComponent } from "./bit-notification.component";
import { BitNotificationFrontComponent } from "./bit-notification-front.component";
import { BitControlMessages } from "./bit-control-messages.component";
import { BitInputComponent } from "./bit-input.component";
import { BitSelectComponent } from "./bit-select.component";
import { BitSelectMultipleComponent } from "./bit-select-multiple.component";
import { BitEditorOldComponent } from "./bit-editor.component";
import { BitDomainValueComponent } from "./bit-domain-value.component";
import { BitColumnBooleanComponent } from "./bit-column-boolean.component";
import { BitFooterComponent } from "./bit-footer.component";
import { BitHeaderComponent } from "./bit-header.component";
import { BitToolbarComponent } from "./bit-toolbar.component";
import { BitBreadCrumbComponent } from "./bit-breadcrumb.component";
import { BitLoadingComponent } from "./bit-loading.component";
import { BitUploadComponent } from "./bit-upload.component";
import { BitFormUploadComponent } from "./bit-form-upload.component";
import { BitHelpComponent } from "./bit-help.component";
import { BitUserControlsComponent } from "./bit-user-controls.component";
import { BitBotonAyudaComponent } from "./bit-boton-ayuda.component";
import { BitStoreBreadCrumbComponent } from "./bit-store-breadcrumb.component";
import { BitStoreHeaderComponent } from "./bit-store-header.component";
import { BitStoreFooterComponent } from "./bit-store-footer.component";
import { BitStoreToolbarComponent } from "./bit-store-toolbar.component";

import * as fromInputComponents from "./form";

export const components: any[] = [
  ...fromInputComponents.components,
  BitDialogComponent,
  BitNotificationComponent,
  BitNotificationFrontComponent,
  BitNotificationFrontComponent,
  BitControlMessages,
  BitInputComponent,
  BitSelectComponent,
  BitSelectMultipleComponent,
  BitEditorOldComponent,
  BitDomainValueComponent,
  BitColumnBooleanComponent,
  BitFooterComponent,
  BitHeaderComponent,
  BitToolbarComponent,
  BitBreadCrumbComponent,
  BitLoadingComponent,
  BitUploadComponent,
  BitFormUploadComponent,
  BitHelpComponent,
  BitUserControlsComponent,
  BitBotonAyudaComponent,
  BitStoreBreadCrumbComponent,
  BitStoreHeaderComponent,
  BitStoreFooterComponent,
  BitStoreToolbarComponent
];

==> bitfront-library-11.0.0.tgz: package/src/app/shared/component/index.ts <==
export * from "./bit-boton-ayuda.component";
export * from "./bit-breadcrumb.component";
export * from "./bit-column-boolean.component";
export * from "./bit-control-messages.component";
export * from "./bit-dialog.component";
export * from "./bit-domain-value.component";
export * from "./bit-footer.component";
export * from "./bit-form-upload.component";
export * from "./bit-header.component";
export * from "./bit-help.component";
export * from "./bit-loading.component";
export * from "./bit-notification-front.component";
export * from "./bit-notification.component";
export * from "./bit-toolbar.component";
export * from "./bit-upload.component";
export * from "./bit-user-controls.component";
export * from "./bit-ng-upload.component";

//nuevos inputs
export * from "./form";
//store
export * from "./bit-store-breadcrumb.component";
export * from "./bit-store-footer.component";
export * from "./bit-store-header.component";
export * from "./bit-store-toolbar.component";

import { BitDialogComponent } from "./bit-dialog.component";
import { BitNotificationComponent } from "./bit-notification.component";
import { BitNotificationFrontComponent } from "./bit-notification-front.component";
import { BitControlMessages } from "./bit-control-messages.component";
import { BitDomainValueComponent } from "./bit-domain-value.component";
import { BitColumnBooleanComponent } from "./bit-column-boolean.component";
import { BitFooterComponent } from "./bit-footer.component";
import { BitHeaderComponent } from "./bit-header.component";
import { BitToolbarComponent } from "./bit-toolbar.component";
import { BitBreadCrumbComponent } from "./bit-breadcrumb.component";
import { BitLoadingComponent } from "./bit-loading.component";
import { BitUploadComponent } from "./bit-upload.component";
import { BitFormUploadComponent } from "./bit-form-upload.component";
import { BitHelpComponent } from "./bit-help.component";
import { BitUserControlsComponent } from "./bit-user-controls.component";
import { BitBotonAyudaComponent } from "./bit-boton-ayuda.component";
import { BitStoreBreadCrumbComponent } from "./bit-store-breadcrumb.component";
import { BitStoreHeaderComponent } from "./bit-store-header.component";
import { BitStoreFooterComponent } from "./bit-store-footer.component";
import { BitStoreToolbarComponent } from "./bit-store-toolbar.component";
import { BitNGUploadComponent } from "./bit-ng-upload.component";

import * as fromInputComponents from "./form";

export const components: any[] = [
  ...fromInputComponents.components,
  BitDialogComponent,
  BitNotificationComponent,
  BitNotificationFrontComponent,
  BitNotificationFrontComponent,
  BitControlMessages,
  BitDomainValueComponent,
  BitColumnBooleanComponent,
  BitFooterComponent,
  BitHeaderComponent,
  BitToolbarComponent,
  BitBreadCrumbComponent,
  BitLoadingComponent,
  BitUploadComponent,
  BitFormUploadComponent,
  BitHelpComponent,
  BitUserControlsComponent,
  BitBotonAyudaComponent,
  BitStoreBreadCrumbComponent,
  BitStoreHeaderComponent,
  BitStoreFooterComponent,
  BitStoreToolbarComponent,
  BitNGUploadComponent
];
